WakaTime
========

Fully automatic time tracking for programmers.

This is the common interface for the WakaTime api. You shouldn't need to directly use this package unless you are creating a new plugin or your text editor's plugin asks you to install the wakatime-cli interface.

Go to http://wakatime.com to install the plugin for your text editor.


Installation
------------

    pip install wakatime


Usage
-----

https://wakatime.com/
